<template>
    <div class="system-user-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <el-input size="default" v-model.trim="searchName" placeholder="真实姓名" style="max-width: 180px"> </el-input>
                <el-button size="default" type="primary" class="ml10" @click="searchByName()">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" class="ml10" @click="reset()">
                  <el-icon>
                    <RefreshLeft />
                  </el-icon>
                  重置
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenUserDialog('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增用户
                </el-button>
            </div>
            <el-table :data="userTableData.data" style="width: 100%">
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="name" label="用户名"/>
                <el-table-column prop="realName" label="真实姓名"/>
                <el-table-column prop="phone" label="手机号"/>
                <el-table-column prop="depName" label="部门"></el-table-column>
                <el-table-column prop="roles" label="关联角色">
                  <template #default="scope">
                    <span>{{ scope.row.roles.map(obj => obj.roleName).join('、') }}</span>
                  </template>
                </el-table-column>
                <el-table-column prop="idType" label="证件类型">
                  <template #default="scope">
                    <span>{{idTypeList.find(item=>item.id == scope.row.idType)?.name}}</span>
                  </template>
                </el-table-column>
                <el-table-column prop="idSerial" label="证件号码"></el-table-column>
                <el-table-column label="操作" width="100">
                    <template #default="scope">
                        <el-button :disabled="scope.row.userName === 'admin'" size="small" text type="primary" @click="onOpenUserDialog('修改', scope.row)">修改</el-button>
                        <el-button style="color: red" :disabled="scope.row.userName === 'admin'" size="small" text type="primary" @click="onRowDel(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="page-position" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="userTableData.listQuery.pageIndex" background v-model:page-size="userTableData.listQuery.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="userTableData.total"> </el-pagination>
            <br />
            <br />
        </el-card>
        <userDialog ref="userRef" @getUserList="initUserTableData"/>
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import userDialog from '/@/views/system/user/component/userDialog.vue';
import { userApi } from '/@/api/systemManage/user';
import { departmentApi } from '/@/api/systemManage/department';
import { useRoleApi } from '/@/api/systemManage/role';

// 定义接口来定义对象的类型
interface TableDataRow {
    userName: string;
    userNickname: string;
    roleSign: string;
    department: string[];
    phone: string;
    email: string;
    sex: string;
    password: string;
    overdueTime: Date;
    status: boolean;
    describe: string;
    createTime: string;
}
interface idType{
  id: number,
  name: string
}

interface TableDataState {
    userTableData: {
        data: Array<TableDataRow>;
        total: number;
        loading: boolean;
        listQuery: {
            roleId: number | null;
            usePage: boolean;
            pageIndex: number;
            pageSize: number;
        };
    };
    idTypeList: Array<idType>
    depList: [];
    roleList: [];
    searchName:string
}

export default defineComponent({
    name: 'systemUser',
    components: { userDialog },
    setup() {
        const userRef = ref();
        const state = reactive<TableDataState>({
            userTableData: {
                data: [],
                total: 0,
                loading: false,
                listQuery: {
                    roleId: 1,
                    usePage: false,
                    pageIndex: 1,
                    pageSize: 10
                }
            },
            idTypeList:[
              {
                id: 1,
                name: '身份证'
              }
            ],
            depList: [],
            roleList: [],
            searchName: ''
        });
        // 初始化表格数据
        const initUserTableData = async () => {
            let res = await userApi().getUserList(state.userTableData.listQuery);
            if (res.data.code === 100) {
                state.userTableData.data = res.data.data;
                state.userTableData.total = res.data.total;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        const searchByName = async () =>{
          if(state.searchName == ''){
            ElMessage({
              type: 'warning',
              message: '请输入搜索内容'
            });
          }else{
            let res = await userApi().getUserLByRealName(state.searchName);
            if (res.data.code === 100) {
              state.userTableData.data = res.data.data
            } else {
              ElMessage({
                type: 'warning',
                message: res.data.msg
              });
            }
          }
        }

        const reset = () =>{
          state.searchName = ''
          initUserTableData()
        }

        const getDepList = async () => {
          let res = await departmentApi().getDepartmentList()
          if (res.data.code === 100) {
            state.depList = res.data.data;
          } else {
            ElMessage({
              type: 'warning',
              message: res.data.msg
            });
          }
        };

        const getRoleData = async () => {
            let res = await useRoleApi().getRoleList();
            if (res.data.code === 100) {
                state.roleList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开新增修改用户弹窗
        const onOpenUserDialog = (type: string, value: any) => {
          console.log('打开',state.depList, state.roleList)
            userRef.value.openDialog(type, value, state.depList, state.roleList);
        };

        // 删除用户
        const onRowDel = (row: TableDataRow) => {
            ElMessageBox.confirm(`此操作将永久删除账户名称：“${row.name}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await userApi().deleteUser(row.id);
                    if (res.data.code === 100) {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initUserTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.userTableData.listQuery.pageSize = val;
            initUserTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.userTableData.listQuery.pageIndex = val;
            initUserTableData();
        };
        // 页面加载时
        onMounted(() => {
            initUserTableData();
            getRoleData();
            getDepList()
        });
        return {
            userRef,
            reset,
            onOpenUserDialog,
            onRowDel,
            onHandleSizeChange,
            initUserTableData,
            searchByName,
            onHandleCurrentChange,
            ...toRefs(state)
        };
    }
});
</script>
<style  scoped>
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
}
</style>
